==> root-ts-0.9.90.tgz: package/service/routeSessionService.ts <==
import { Service } from "../lib/service"
import * as express from "express"
import { MongodbService } from "./mongodbService"
import { ExpressService } from "./expressService"
import * as ConnectMongo from "connect-mongo"
import * as ExpressSession from "express-session"
const MongoStore = ConnectMongo(ExpressSession);
import * as Session from "express-session"

export class RouteSessionService extends Service<RouteSessionService.Settings> {
    name: "RouteSessionService" = "RouteSessionService"
    dependencies: ["ExpressService", "MongodbService"] = ["ExpressService", "MongodbService"]
    services: {
        ExpressService: ExpressService
        MongodbService: MongodbService
    }
    asBuiltIn() {
        console.log(`RouteService default use MongodbService and default secret.`)
    }
    constructor(settings: RouteSessionService.Settings) {
        super({
            http: {
                session: {
                    secret: null,
                    resave: false,
                    maxAge: null,
                    saveUninitialized: false
                }
            }
        }, settings)
    }
    defaultSecret = "default-session-secret"
    // 31 day
    private defaultMaxAge = 1000 * 60 * 60 * 24 * 31
    initialize() {
        let {
            secret, resave, maxAge, saveUninitialized
        } = this.settings.http.session
        this.services.ExpressService.server.use(ExpressSession({
            secret: secret || this.defaultSecret
            , store: new MongoStore({ db: this.services.MongodbService.db, ttl: maxAge || this.defaultMaxAge })
            , resave: resave || false
            , saveUninitialized: saveUninitialized || false
        }))
    }
}

==> root-ts-0.10.3.tgz: package/service/routeSessionService.ts <==
import { Service } from "../lib/service"
import * as express from "express"
import { MongodbService } from "./mongodbService"
import { ExpressService } from "./expressService"
import * as ConnectMongo from "connect-mongo"
import * as ExpressSession from "express-session"
const MongoStore = ConnectMongo(ExpressSession);
import * as Session from "express-session"

export class RouteSessionService extends Service<Type.Root.RouteSessionService.Settings> {
    name: "RouteSessionService" = "RouteSessionService"
    dependencies: ["ExpressService", "MongodbService"] = ["ExpressService", "MongodbService"]
    services: {
        ExpressService: ExpressService
        MongodbService: MongodbService
    }
    asBuiltIn() {
        console.log(`RouteService default use MongodbService and default secret.`)
    }
    constructor(settings: Type.Root.RouteSessionService.Settings) {
        super({
            http: {
                session: {
                    secret: null,
                    resave: false,
                    maxAge: null,
                    saveUninitialized: false
                }
            }
        }, settings)
    }
    defaultSecret = "default-session-secret"
    // 31 day
    private defaultMaxAge = 1000 * 60 * 60 * 24 * 31
    initialize() {
        let {
            secret, resave, maxAge, saveUninitialized
        } = this.settings.http.session
        this.services.ExpressService.server.use(ExpressSession({
            secret: secret || this.defaultSecret
            , store: new MongoStore({ db: this.services.MongodbService.db, ttl: maxAge || this.defaultMaxAge })
            , resave: resave || false
            , saveUninitialized: saveUninitialized || false
        }))
    }
}
